{% extends 'base.html' %}

{% block breadcrumb %}
  {% include 'crudlfap/_breadcrumb_object.html' %}
{% endblock %}

{% block content %}
<div class="card-panel">
  <table class="table">
    <thead class="thead-inverse">
      {% for field in view.display_fields %}
      <tr>
          <th>
              {{ field['field'].verbose_name.capitalize() }}
          </th>
          <td>
              {{ field['value'] }}
          </td>
      </tr>
      {% endfor %}
    </tbody>
  </table>
</div>
{% endblock %}
